==> recital-0.4.0.tar.gz: recital-0.4.0/recital/api/reports/get_report.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.http_validation_error import HTTPValidationError
from ...models.report_output import ReportOutput
from ...types import Response


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    report_id: int,
) -> Dict[str, Any]:
    url = "{}/api/v1/reports/{report_id}/".format(client.base_url, report_id=report_id)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[Union[ReportOutput, None, None, None, HTTPValidationError]]:
    if response.status_code == 200:
        response_200 = ReportOutput.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 403:
        response_403 = None

        return response_403
    if response.status_code == 404:
        response_404 = None

        return response_404
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[Union[ReportOutput, None, None, None, HTTPValidationError]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    report_id: int,
) -> Response[Union[ReportOutput, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        report_id=report_id,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    report_id: int,
) -> Optional[Union[ReportOutput, None, None, None, HTTPValidationError]]:
    """Gets a single report metadata.

    This route only returns informations about a report.
    To download it, use the dedicated `reports/{id}/download` endpoint.

    Users can only access reports related to background tasks they ran."""

    return sync_detailed(
        client=client,
        report_id=report_id,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    report_id: int,
) -> Response[Union[ReportOutput, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        report_id=report_id,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    report_id: int,
) -> Optional[Union[ReportOutput, None, None, None, HTTPValidationError]]:
    """Gets a single report metadata.

    This route only returns informations about a report.
    To download it, use the dedicated `reports/{id}/download` endpoint.

    Users can only access reports related to background tasks they ran."""

    return (
        await asyncio_detailed(
            client=client,
            report_id=report_id,
        )
    ).parsed

==> recital-0.6.0.tar.gz: recital-0.6.0/recital/api/reports/get_report.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.http_validation_error import HTTPValidationError
from ...models.report_output import ReportOutput
from ...types import Response


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    report_id: int,
) -> Dict[str, Any]:
    url = "{}/api/v1/reports/{report_id}/".format(client.base_url, report_id=report_id)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[HTTPValidationError, None, ReportOutput]]:
    if response.status_code == 200:
        response_200 = ReportOutput.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 403:
        response_403 = None

        return response_403
    if response.status_code == 404:
        response_404 = None

        return response_404
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[HTTPValidationError, None, ReportOutput]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    report_id: int,
) -> Response[Union[HTTPValidationError, None, ReportOutput]]:
    kwargs = _get_kwargs(
        client=client,
        report_id=report_id,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    report_id: int,
) -> Optional[Union[HTTPValidationError, None, ReportOutput]]:
    """Gets a single report metadata.

    This route only returns informations about a report.
    To download it, use the dedicated `reports/{id}/download` endpoint.

    Users can only access reports related to background tasks they ran."""

    return sync_detailed(
        client=client,
        report_id=report_id,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    report_id: int,
) -> Response[Union[HTTPValidationError, None, ReportOutput]]:
    kwargs = _get_kwargs(
        client=client,
        report_id=report_id,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    report_id: int,
) -> Optional[Union[HTTPValidationError, None, ReportOutput]]:
    """Gets a single report metadata.

    This route only returns informations about a report.
    To download it, use the dedicated `reports/{id}/download` endpoint.

    Users can only access reports related to background tasks they ran."""

    return (
        await asyncio_detailed(
            client=client,
            report_id=report_id,
        )
    ).parsed
